library nektor.storage;

import 'dart:convert';
import 'dart:developer';
import 'dart:io';

import 'package:path_provider/path_provider.dart';

class JsonStorage {
  File _jsonFile;
  Directory _storageDirectory;
  String _fileName;
  List<Map<String, String>> _fileContent = List();

  JsonStorage(this._fileName);

  Future<bool> initState() async {
    // Get Doc directory
    _storageDirectory = await getApplicationDocumentsDirectory();
    // Build data file
    _jsonFile = File("${_storageDirectory.path}/$_fileName");

    // I know that _jsonFile.existsSync() exists, but I want to trigger people by waiting for a Async function in Sync
    if (!(await _jsonFile.exists())) {
      // Create data file if not exists
      _jsonFile.create(recursive: true);
    } else {
      // Read data file if exists
      final jsonData = await _jsonFile.readAsString();
      List<dynamic> dta = json.decode(jsonData);
      dta.forEach((obj) {
        if (obj is Map<String, String>) {
          _fileContent.add(obj);
        }
      });
    }

    // If data is not empty, print
    if (_fileContent.isNotEmpty) {
      for (var kv in _fileContent) {
        kv.forEach((k, v) {
          log("Key: $k, Value: $v");
        });
      }
    }

    return Future.sync(() {
      return true;
    });
  }

  // Write data to file
  Future<void> syncFile() async {
    await _jsonFile.writeAsString(json.encode(_fileContent));
  }

  // Return prepared data
  List<Map<String, String>> getData() {
    return _fileContent;
  }

  // Add new Lending data
  Future<void> add(Map<String, String> jsonData) async {
    // Append to content
    _fileContent.add(jsonData);

    // Write to disk
    await syncFile();
  }
}
